@@ -2,19 +2,18 @@
 
 from .base import HypervisorPlatform
 from .disk import VirtualDisk
-from .hypervisor import Hypervisor
-from .network import VirtualNetwork
-from .snapshot import VirtualSnapshot
-from .storage import Storage
+from .hypervisor import Hypervisor, Storage
+from .network import VirtualNetworInteface
+from .snapshot import Snapshot
 from .vm import VirtualMachine, VirtualMachineState
 
 __all__ = [
     "HypervisorPlatform",
-    "VirtualDisk",
     "Hypervisor",
-    "VirtualNetwork",
-    "VirtualSnapshot",
-    "Storage",
+    "VirtualNetworInteface",
     "VirtualMachine",
     "VirtualMachineState",
+    "VirtualDisk",
+    "Snapshot",
+    "Storage",
 ]
