@@ -21,7 +21,7 @@ class VirtualDisk:
     def __post_init__(self):
         object.__setattr__(self, "path", Path(self.path))
 
-    def resize(self, required_size: int) -> None:
+    async def resize(self, required_size: int) -> None:
         """Resize the virtual disk"""
-        new_size = self.driver.resize(required_size)
+        new_size = await self.driver.resize(required_size)
         object.__setattr__(self, "size", new_size)
