@@ -4,7 +4,7 @@ from dataclasses import dataclass
 
 
 @dataclass(frozen=True)
-class VirtualNetwork:
+class VirtualNetworInteface:
     """Data structure that contains the virtual machine network info"""
 
     mac: str
