@@ -8,27 +8,28 @@ from .drivers.kvm import KernelVirtualSnapshotDriver
 
 
 @dataclass(frozen=True)
-class VirtualSnapshot:
+class Snapshot:
     """Data structure that contains the virtual machine snapshot info"""
 
     driver: HyperVirtualSnapshotDriver | KernelVirtualSnapshotDriver = field(repr=False)
     created_at: datetime = field(init=False)
     created_at_ts: InitVar[int]
-    local_id: str
     name: str
     parent_name: str
     is_applied: bool
     cpus: int
     ram: int
     description: str | None = None
+    id: str = field(init=False)
 
     def __post_init__(self, created_at_ts: int):
         object.__setattr__(self, "created_at", datetime.fromtimestamp(created_at_ts))
+        object.__setattr__(self, "id", self.driver.id)
 
-    def apply(self) -> None:
+    async def apply(self) -> None:
         """Apply the snapshot"""
-        self.driver.apply()
+        await self.driver.apply()
 
-    def destroy(self) -> None:
+    async def destroy(self) -> None:
         """Destroy the snapshot"""
-        self.driver.destroy()
+        await self.driver.destroy()
