@@ -9,4 +9,4 @@ class Storage:
 
     name: str
     size: int
-    used: int
+    free: int
